@@ -343,6 +343,13 @@ static int ltspfs_getattr(const char *path, struct stat *stbuf)
     stbuf->st_uid = fc->uid;
     stbuf->st_gid = fc->gid;
 
+    /*
+     * Also, in order to make sure that all files are umask 700, we'll
+     * manipulate the st_mode at this point.
+     */
+
+    stbuf->st_mode = stbuf->st_mode & (S_IFDIR | S_IFREG | 0700);
+
     if (!xdr_u_longlong_t(&in, &stbuf->st_rdev))
         return -EACCES;
     if (!xdr_longlong_t(&in, &stbuf->st_size))
@@ -1120,9 +1127,11 @@ int main(int argc, char *argv[])
      * The connection's plumbed.  Issue our mount command.
      */
 
-    if (ltspfs_sendauth() != 0) {
-        fprintf(stderr, "Authentication failed.\n");
-        exit(1);
+    if (getenv("LTSPFS_NOAUTH") == NULL) {
+	if (ltspfs_sendauth() != 0) {
+	    fprintf(stderr, "Authentication failed.\n");
+	    exit(1);
+	}
     }
 
     handle_mount(mountpoint);
