@@ -78,7 +78,7 @@ void sig_chld(int signo)
 void sig_term(int signo)
 {
     (void) signo;
-    info("Recieved SIGTERM, shutting down\n");
+    info("Received SIGTERM, shutting down\n");
     exit(OK);
 }
 
